@@ -1,63 +1,61 @@
-/** 
+/*
  * XML Security Library (http://www.aleksey.com/xmlsec).
  *
- * Version information
  *
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
- * 
- * Copyrigth (C) 2002-2003 Aleksey Sanin <aleksey@aleksey.com>
+ *
+ * Copyright (C) 2002-2024 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
+ */
+/**
+ * SECTION:version
+ * @Short_description: Version macros.
+ * @Stability: Stable
+ *
  */
 #ifndef __XMLSEC_VERSION_H__
-#define __XMLSEC_VERSION_H__    
+#define __XMLSEC_VERSION_H__
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
 /**
  * XMLSEC_VERSION:
  *
  * The library version string in the format
- * "<major-number>.<minor-number>.<sub-minor-number>".
+ * "$major_number.$minor_number.$sub_minor_number".
  */
-#define XMLSEC_VERSION			"1.0.1"
-
-/**
- * XMLSEC_PACKAGE:
- *
- * The library packaqge name.
- */
-#define XMLSEC_PACKAGE			"xmlsec1"
+#define XMLSEC_VERSION            "1.2.41"
 
 /**
  * XMLSEC_VERSION_MAJOR:
  *
  * The library major version number.
  */
-#define XMLSEC_VERSION_MAJOR		1
+#define XMLSEC_VERSION_MAJOR        1
 
 /**
  * XMLSEC_VERSION_MINOR:
  *
  * The library minor version number.
  */
-#define XMLSEC_VERSION_MINOR		0
+#define XMLSEC_VERSION_MINOR        2
 
 /**
  * XMLSEC_VERSION_SUBMINOR:
  *
  * The library sub-minor version number.
  */
-#define XMLSEC_VERSION_SUBMINOR		1
+#define XMLSEC_VERSION_SUBMINOR        41
 
 /**
  * XMLSEC_VERSION_INFO:
  *
  * The library version info string in the format
- * "<major-number>+<minor-number>:<sub-minor-number>:<minor-number>".
+ * "$major_number+$minor_number:$sub_minor_number:$minor_number".
  */
-#define XMLSEC_VERSION_INFO		"1:1:0"
+#define XMLSEC_VERSION_INFO        "3:41:2"
 
 
 #ifdef __cplusplus
